# gjob

[![All Contributors](https://img.shields.io/github/all-contributors/blakeNaccarato/gjob?color=ee8449&style=flat-square)](#contributors)

Process exported emails like those from Google Careers aka "Job Alerts from Google".

## Project information

- [Changes](<https://blakeNaccarato.github.io/gjob/changelog.html>)
- [Docs](<https://blakeNaccarato.github.io/gjob>)
- [Contributing](<https://blakeNaccarato.github.io/gjob/contributing.html>)

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
